This is a package covering nearest neighbor (nn) based estimators for measures of information theory: 
entropy, Kullback-Leibler divergence and mutual information. 
Application is on continous variables that can be multidimensional.

The package includes ideas of several publications (see code), including our contribution:
A Bayesian nearest neighbor mutual information estimator (BannMI). BannMI is designed for
application on phsophoproteomic data to analyse potential protein-protein interactions.    

